@@ -1,18 +1,14 @@
-{-# LANGUAGE CPP #-}
 {-# LANGUAGE BangPatterns #-}
 {-# LANGUAGE NoMonomorphismRestriction #-}
 {-# OPTIONS_GHC -funbox-strict-fields #-}
 {-# OPTIONS_HADDOCK hide #-}
 
-#ifndef MIN_VERSION_base
-#defined MIN_VERSION_base(x,y,z) 1
-#endif
-
-{- Evaluates the paramaterized terminfo string capability with the given parameters.
- -
- -}
-module Data.Terminfo.Eval (writeCapExpr)
-    where
+-- | Evaluates the paramaterized terminfo string capability with the
+-- given parameters.
+module Data.Terminfo.Eval
+  ( writeCapExpr
+  )
+where
 
 import Blaze.ByteString.Builder.Word
 import Blaze.ByteString.Builder
@@ -27,10 +23,6 @@ import Data.List
 
 import qualified Data.Vector.Unboxed as Vector
 
-#if !(MIN_VERSION_base(4,8,0))
-import Data.Word
-#endif
-
 -- | capability evaluator state
 data EvalState = EvalState
     { evalStack :: ![CapParam]
@@ -83,7 +75,7 @@ writeCapOp DecOut = do
     p <- pop
     forM_ (show p) $ tell.writeWord8.toEnum.fromEnum
 writeCapOp CharOut = do
-    pop >>= tell.writeWord8.toEnum.fromEnum 
+    pop >>= tell.writeWord8.toEnum.fromEnum
 writeCapOp (PushParam pn) = do
     readParam pn >>= push
 writeCapOp (PushValue v) = do
@@ -91,13 +83,14 @@ writeCapOp (PushValue v) = do
 writeCapOp (Conditional expr parts) = do
     writeCapOps expr
     writeContitionalParts parts
-    where 
+    where
         writeContitionalParts [] = return ()
         writeContitionalParts ((trueOps, falseOps) : falseParts) = do
             -- (man 5 terminfo)
-            -- Usually the %? expr part pushes a value onto the stack, and %t pops  it  from  the
-            -- stack, testing if it is nonzero (true).  If it is zero (false), control
-            -- passes to the %e (else) part.
+            -- Usually the %? expr part pushes a value onto the stack,
+            -- and %t pops it from the stack, testing if it is nonzero
+            -- (true). If it is zero (false), control passes to the %e
+            -- (else) part.
             v <- pop
             if v /= 0
                 then writeCapOps trueOps
@@ -137,4 +130,3 @@ writeCapOp CompareGt = do
     v1 <- pop
     v0 <- pop
     push $ if v0 > v1 then 1 else 0
-
