@@ -13,7 +13,7 @@
 --   values in the "Graphics.Vty.Attributes" module.
 --
 -- Vty uses threads internally, so programs made with Vty need to be
--- compiled with the threaded runtime using the GHC `-threaded` option.
+-- compiled with the threaded runtime using the GHC @-threaded@ option.
 --
 -- @
 --  import "Graphics.Vty"
@@ -51,7 +51,10 @@ import Graphics.Vty.Output.Interface
 import Graphics.Vty.Picture
 import Graphics.Vty.Image
 import Graphics.Vty.Attributes
+import Graphics.Vty.UnicodeWidthTable.IO
+import Graphics.Vty.UnicodeWidthTable.Install
 
+import qualified Control.Exception as E
 import Control.Monad (when)
 import Control.Concurrent.STM
 
@@ -65,7 +68,7 @@ import Data.Semigroup ((<>))
 --
 -- The use of Vty typically follows this process:
 --
---    1. Initialize vty
+--    1. Initialize vty with 'mkVty' (this takes control of the terminal).
 --
 --    2. Use 'update' to display a picture.
 --
@@ -73,31 +76,33 @@ import Data.Semigroup ((<>))
 --
 --    4. Depending on the event, go to 2 or 5.
 --
---    5. Shutdown vty.
+--    5. Shutdown vty and restore the terminal state with 'shutdown'. At
+--    this point the 'Vty' handle cannot be used again.
 --
 -- Operations on Vty handles are not thread-safe.
-data Vty = Vty
-    { -- | Outputs the given 'Picture'.
-      update :: Picture -> IO ()
-      -- | Return the next 'Event' or block until one becomes available.
-    , nextEvent :: IO Event
-      -- | Non-blocking version of 'nextEvent'.
-    , nextEventNonblocking :: IO (Maybe Event)
-      -- | The input interface. See 'Input'.
-    , inputIface :: Input
-      -- | The output interface. See 'Output'.
-    , outputIface :: Output
-      -- | Refresh the display. If other programs output to the terminal
-      -- and mess up the display then the application might want to
-      -- force a refresh using this function.
-    , refresh :: IO ()
-      -- | Clean up after vty. A call to this function is necessary to
-      -- cleanly restore the terminal state before application exit. The
-      -- above methods will throw an exception if executed after this is
-      -- executed. Idempotent.
-    , shutdown :: IO ()
-    , isShutdown :: IO Bool
-    }
+data Vty =
+    Vty { update :: Picture -> IO ()
+        -- ^ Outputs the given 'Picture'.
+        , nextEvent :: IO Event
+        -- ^ Return the next 'Event' or block until one becomes
+        -- available.
+        , nextEventNonblocking :: IO (Maybe Event)
+        -- ^ Non-blocking version of 'nextEvent'.
+        , inputIface :: Input
+        -- ^ The input interface. See 'Input'.
+        , outputIface :: Output
+        -- ^ The output interface. See 'Output'.
+        , refresh :: IO ()
+        -- ^ Refresh the display. If other programs output to the
+        -- terminal and mess up the display then the application might
+        -- want to force a refresh using this function.
+        , shutdown :: IO ()
+        -- ^ Clean up after vty. A call to this function is necessary to
+        -- cleanly restore the terminal state before application exit.
+        -- The above methods will throw an exception if executed after
+        -- this is executed. Idempotent.
+        , isShutdown :: IO Bool
+        }
 
 -- | Create a Vty handle. At most one handle should be created at a time
 -- for a given terminal device.
@@ -110,12 +115,51 @@ data Vty = Vty
 mkVty :: Config -> IO Vty
 mkVty appConfig = do
     config <- (<> appConfig) <$> userConfig
-    input  <- inputForConfig config
-    out    <- outputForConfig config
-    intMkVty input out
 
-intMkVty :: Input -> Output -> IO Vty
-intMkVty input out = do
+    when (allowCustomUnicodeWidthTables config /= Just False) $
+        installCustomWidthTable config
+
+    input <- inputForConfig config
+    out <- outputForConfig config
+    internalMkVty input out
+
+installCustomWidthTable :: Config -> IO ()
+installCustomWidthTable c = do
+    let doLog s = case debugLog c of
+            Nothing -> return ()
+            Just path -> appendFile path $ "installWidthTable: " <> s <> "\n"
+
+    customInstalled <- isCustomTableReady
+    when (not customInstalled) $ do
+        mTerm <- currentTerminalName
+        case mTerm of
+            Nothing ->
+                doLog "No current terminal name available"
+            Just currentTerm ->
+                case lookup currentTerm (termWidthMaps c) of
+                    Nothing ->
+                        doLog "Current terminal not found in custom character width mapping list"
+                    Just path -> do
+                        tableResult <- E.try $ readUnicodeWidthTable path
+                        case tableResult of
+                            Left (e::E.SomeException) ->
+                                doLog $ "Error reading custom character width table " <>
+                                        "at " <> show path <> ": " <> show e
+                            Right (Left msg) ->
+                                doLog $ "Error reading custom character width table " <>
+                                        "at " <> show path <> ": " <> msg
+                            Right (Right table) -> do
+                                installResult <- E.try $ installUnicodeWidthTable table
+                                case installResult of
+                                    Left (e::E.SomeException) ->
+                                        doLog $ "Error installing unicode table (" <>
+                                                show path <> ": " <> show e
+                                    Right () ->
+                                        doLog $ "Successfully installed Unicode width table " <>
+                                                " from " <> show path
+
+internalMkVty :: Input -> Output -> IO Vty
+internalMkVty input out = do
     reserveDisplay out
 
     shutdownVar <- atomically $ newTVar False
