@@ -1,7 +1,18 @@
 {-# LANGUAGE DeriveGeneric #-}
 {-# LANGUAGE DeriveAnyClass #-}
+
 module Graphics.Vty.Attributes.Color
   ( Color(..)
+
+  -- ** Fixed Colors
+  -- | Standard 8-color ANSI terminal color codes.
+  --
+  -- Note that these map to colors in the terminal's custom palette. For
+  -- instance, `white` maps to whatever the terminal color theme uses for
+  -- white.
+  --
+  -- Use these functions if you want to make apps that fit the terminal theme.
+  -- If you want access to more/stronger colors use `rgbColor`
   , black
   , red
   , green
@@ -10,6 +21,8 @@ module Graphics.Vty.Attributes.Color
   , magenta
   , cyan
   , white
+
+  -- | Bright/Vivid variants of the standard 8-color ANSI
   , brightBlack
   , brightRed
   , brightGreen
@@ -18,6 +31,9 @@ module Graphics.Vty.Attributes.Color
   , brightMagenta
   , brightCyan
   , brightWhite
+  -- ** Creating Colors From RGB
+  , rgbColor
+  , module Graphics.Vty.Attributes.Color240
   )
 where
 
@@ -25,6 +41,8 @@ import Data.Word
 import GHC.Generics
 import Control.DeepSeq
 
+import Graphics.Vty.Attributes.Color240
+
 -- | Abstract data type representing a color.
 --
 -- Currently the foreground and background color are specified as points
@@ -80,7 +98,6 @@ import Control.DeepSeq
 data Color = ISOColor !Word8 | Color240 !Word8
     deriving ( Eq, Show, Read, Generic, NFData )
 
--- | Standard 8-color ANSI terminal color codes.
 black, red, green, yellow, blue, magenta, cyan, white :: Color
 black  = ISOColor 0
 red    = ISOColor 1
@@ -91,7 +108,6 @@ magenta= ISOColor 5
 cyan   = ISOColor 6
 white  = ISOColor 7
 
--- | Bright/Vivid variants of the standard 8-color ANSI
 brightBlack, brightRed, brightGreen, brightYellow :: Color
 brightBlue, brightMagenta, brightCyan, brightWhite :: Color
 brightBlack  = ISOColor 8
@@ -102,3 +118,10 @@ brightBlue   = ISOColor 12
 brightMagenta= ISOColor 13
 brightCyan   = ISOColor 14
 brightWhite  = ISOColor 15
+
+
+-- | Create a Vty 'Color' (in the 240 color set) from an RGB triple.
+-- This function is lossy in the sense that we only internally support 240 colors but the
+-- #RRGGBB format supports 16^3 colors.
+rgbColor :: Integral i => i -> i -> i -> Color
+rgbColor r g b = Color240 (rgbColorToColor240 r g b)
