@@ -12,16 +12,16 @@ import Graphics.Vty.Span
 
 import qualified Data.Vector as Vector
 
-rowOpsEffectedColumns :: DisplayOps -> [Int]
-rowOpsEffectedColumns ops
-    = Vector.toList $ Vector.map spanOpsEffectedColumns ops
+rowOpsAffectedColumns :: DisplayOps -> [Int]
+rowOpsAffectedColumns ops
+    = Vector.toList $ Vector.map spanOpsAffectedColumns ops
 
 allSpansHaveWidth :: DisplayOps -> Int -> Bool
 allSpansHaveWidth ops expected
-    = all (== expected) $ Vector.toList $ Vector.map spanOpsEffectedColumns ops
+    = all (== expected) $ Vector.toList $ Vector.map spanOpsAffectedColumns ops
 
-spanOpsEffectedRows :: DisplayOps -> Int
-spanOpsEffectedRows ops
+spanOpsAffectedRows :: DisplayOps -> Int
+spanOpsAffectedRows ops
     = toEnum $ length (filter (not . null . Vector.toList) (Vector.toList ops))
 
 type SpanConstructLog = [SpanConstructEvent]
