@@ -323,14 +323,14 @@ addUnclippedText a txt = do
     let op = TextSpan a usedDisplayColumns
                       (fromIntegral $ TL.length txt)
                       txt
-        usedDisplayColumns = wcswidth $ TL.unpack txt
+        usedDisplayColumns = wctlwidth txt
     use rowOffset >>= snocOp op
 
 addRowCompletion :: DisplayRegion -> Int -> BlitM s ()
 addRowCompletion displayRegion row = do
     allRowOps <- view mrowOps
     rowOps <- lift $ lift $ MVector.read allRowOps row
-    let endX = spanOpsEffectedColumns rowOps
+    let endX = spanOpsAffectedColumns rowOps
     when (endX < regionWidth displayRegion) $ do
         let ow = regionWidth displayRegion - endX
         snocOp (Skip ow) row
@@ -343,6 +343,6 @@ snocOp !op !row = do
     lift $ lift $ do
         ops <- MVector.read theMrowOps row
         let ops' = Vector.snoc ops op
-        when (spanOpsEffectedColumns ops' > regionWidth theRegion)
+        when (spanOpsAffectedColumns ops' > regionWidth theRegion)
              $ fail $ "row " ++ show row ++ " now exceeds region width"
         MVector.write theMrowOps row ops'
